==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/hu.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Kezelése album Gallary paraméterek");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Kezelés Galéria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Teljes méretű kép szélessége");
define('MANAGE_GALLERY_FULL_HEIGHT', "Teljes méretű kép magassága");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail kép szélessége");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail kép magassága");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Őrizze Thumb képarány");
define('MANAGE_GALLERY_SHOW_TITLES', "Címek megjelenítése");
define('MANAGE_GALLERY_DISABLE_SORT', "letiltása rendezése");
define('MANAGE_GALLERY_DELETE_IMAGE', "kép törlése");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kattintson a &quot;Frissítés&quot; közzétételére <br /> a feltöltött képeket.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Minden kép lett átméretezve és beállítások elmentve.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Hiba átméretezés a kép vagy a beállítások mentése.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "A kép (ek) már feltöltött.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Hiba történt a kép feltöltése (ek).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "A kívánt fájl feltöltésére nem kép.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "A kívánt fájl feltölteni, túl nagy.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "A cím lett mentve.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Biztosan törölni szeretné kép");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "A képet törölték.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Hiba törlése a képet.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Mentési paramétereinek és átméretezés képek, kérem várjon ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Töltés, kérem várjon ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "A sorrend nem lett elmentve. Szeretné menteni a rendezési sorrend?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "A kép rendezési sorrend lett mentve.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Hiba történt a kép elmentése sort.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/hu.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Kezelése album Gallary paraméterek");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Kezelés Galéria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Teljes méretű kép szélessége");
define('MANAGE_GALLERY_FULL_HEIGHT', "Teljes méretű kép magassága");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail kép szélessége");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail kép magassága");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Őrizze Thumb képarány");
define('MANAGE_GALLERY_SHOW_TITLES', "Címek megjelenítése");
define('MANAGE_GALLERY_DISABLE_SORT', "letiltása rendezése");
define('MANAGE_GALLERY_DELETE_IMAGE', "kép törlése");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kattintson a &quot;Frissítés&quot; közzétételére <br /> a feltöltött képeket.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Minden kép lett átméretezve és beállítások elmentve.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Hiba átméretezés a kép vagy a beállítások mentése.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "A kép (ek) már feltöltött.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Hiba történt a kép feltöltése (ek).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "A kívánt fájl feltöltésére nem kép.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "A kívánt fájl feltölteni, túl nagy.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "A cím lett mentve.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Biztosan törölni szeretné kép");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "A képet törölték.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Hiba törlése a képet.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Mentési paramétereinek és átméretezés képek, kérem várjon ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Töltés, kérem várjon ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "A sorrend nem lett elmentve. Szeretné menteni a rendezési sorrend?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "A kép rendezési sorrend lett mentve.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Hiba történt a kép elmentése sort.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "A feltölteni kívánt fájl nagyobb, mint a &#39;upload_max_filesize&#39; vagy &#39;post_max_size&#39; PHP beállítások. Vegye fel a kapcsolatot a rendszergazdával, hogy növelje ezeket a korlátokat.");
?>
